/**
 * Copyright 2008 Peach Jean Solutions
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.xj4.spi;

import java.util.List;

import org.junit.runners.model.FrameworkMethod;

/**
 * An extension point for replacing the default method handling of JUnit with a custom process.  The handler is
 * responsible for determining if it can handle a method, validating methods that it can handle, and then actually
 * handling them.  Only one method handler is selected to handle any particular method.
 *
 * @author jbunting
 */
public interface MethodHandler {

  /**
   * Allows the handler to determine if it applies to the supplied method.  This should typically use a special
   * annotation or something of the sort to make this determination.
   * @param method the method to handle
   * @return true if this handler applies to the given method, false otherwise
   */
  boolean canHandle(FrameworkMethod method);

  /**
   * Handle the given method by creating custom FrameworkMethod objects that will invoke the method properly.
   * @param method the method as created by JUnit
   * @return a list of framework methods that will handle this method appropriately
   */
  List<FrameworkMethod> handle(FrameworkMethod method);

  /**
   * Validate a given method.  The provided FrameworkMethod is that generated by JUnit.
   * @param method the method generated by JUnit
   * @param errors a list of validation errors - any new ones should be added to this list
   */
  void validate(FrameworkMethod method, List<Throwable> errors);
}
