/**
 * Copyright 2008 Peach Jean Solutions
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.xj4.spi;

import org.xj4.XJ4TestClass;

/**
 * Extension point for generating method handlers for a particular test class.  This can be used to simply provide the
 * test class object to the method handler, or to customize the method handler for the particular test class.  If
 * {@link #create} returns <code>null</code> then it is simply ignored.
 *
 * @author jbunting
 */
public interface MethodHandlerFactory {

  /**
   * Create a method handler object for this test class.  This method may return <code>null</code> to indicate that this
   * extension does not care to handle methods in this class.
   *
   * @param testClass the test class to handle methods for
   * @return the method handler, or null if declining to handle methods for this class
   */
  public MethodHandler create(XJ4TestClass testClass);
}
