/**
 * Copyright 2008 Peach Jean Solutions
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.xj4.spi;

import java.util.List;

import org.junit.runners.model.FrameworkMethod;
import org.xj4.XJ4TestClass;

/**
 * An extension point for performing actions before and after a test method.  This is akin to
 * {@link org.junit.Before @Before) and {@link org.junit.After @After} methods.
 *
 * @author Jared Bunting
 */
public interface MethodWrapperSource {

  /**
   * Provides a list of test wrappers for the test method.
   * @param testClass the test class
   * @param method the method that will be invoked
   * @param target the target test object
   * @return a list of wrappers
   */
  public List<TestWrapper> generateWrapper(XJ4TestClass testClass, FrameworkMethod method, Object target);
}
