/**
 * Copyright 2008 Peach Jean Solutions
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.xj4.spi;

/**
 * A test wrapper is designed to do something before, and something after a test.  These are returned by the wrapper
 * source extension points.
 *
 * @author Jared Bunting
 * @see ClassWrapperSource, MethodWrapperSource
 */
public interface TestWrapper {

  /**
   * Performs actions intended to be performed before the test.
   * @throws Throwable if something goes wrong
   */
  public void doBefore() throws Throwable;

  /**
   * Performs actions intended to be performed after the test.
   * @throws Throwable if something goes wrong
   */
  public void doAfter() throws Throwable;
}
