package org.xj4.spi;

import java.util.List;

/**
 * The core of xj4's extensibility.  Any extension must implement this interface, and then provide the appropriate
 * extension point objects through the appropriate getter methods.
 *
 * @author Jared Bunting
 */
public interface XJ4ExtensionProvider {

  /**
   * Gets the method handler factories provided.  These in turn will provide {@link MethodHandler}s.
   * @return the list of factories
   */
  List<MethodHandlerFactory> getMethodHandlerFactories();

  /**
   * Gets the method wrapper sources provided.  These in turn will provide {@link TestWrapper}s that apply to individual
   * test methods.
   * @return the list of sources
   */
  List<MethodWrapperSource> getMethodWrapperSources();

  /**
   * Gets the clas wrapper sources provided.  These in turn will provide {@link TestWrapper}s that apply to whole test
   * classes.
   * @return the list of sources
   */
  List<ClassWrapperSource> getClassWrapperSources();

  /**
   * Gets the test class validators.  These are intended to ensure that the test class doesn't have any errors in its
   * writing that would preclude even running a test.
   * @return the list of validators
   */
  List<TestClassValidator> getTestClassValidators();
}
