/**
 * Copyright 2008 Peach Jean Solutions
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.xj4.spi;

import java.util.List;
import java.util.Collections;

/**
 * Base class intended for implementation of XJ4ExtensionProvider.  Extending this class instead of implementing the
 * interface directly will insulate implementations from future additions to the interface. 
 *
 * @author Jared Bunting
 */
public abstract class XJ4ExtensionProviderBase implements XJ4ExtensionProvider {
  public List<MethodHandlerFactory> getMethodHandlerFactories() {
    return conditionalList(getMethodHandlerFactory());
  }

  protected MethodHandlerFactory getMethodHandlerFactory() {
    return null;
  }

  public List<MethodWrapperSource> getMethodWrapperSources() {
    return conditionalList(getMethodWrapperSource());
  }

  protected MethodWrapperSource getMethodWrapperSource() {
    return null;
  }

  public List<ClassWrapperSource> getClassWrapperSources() {
    return conditionalList(getClassWrapperSource());
  }

  protected ClassWrapperSource getClassWrapperSource() {
    return null;
  }

  public List<TestClassValidator> getTestClassValidators() {
    return conditionalList(getTestClassValidator());
  }

  protected TestClassValidator getTestClassValidator() {
    return null;
  }

  protected <T> List<T> conditionalList(T item) {
    return item == null ? Collections.EMPTY_LIST : Collections.singletonList(item);
  }
}
